package br.usp.ime.mac5855.knn;

/**
 * Esta interface define um comparador que calcula a distncia entre dois
 * objetos, a ser usado no algoritmo Knn.
 * Esta interface  de certa forma, bem semelhante  interface
 * {@linkplain java.util.Comparator}. Porm, ao invs de utilizar um {@code int}
 * para definir qual elemento  maior que o outro, esta interface utiliza um
 * {@code double} para definir qual  a distncia entre dois elementos.
 *
 * @param <E> O tipo de objeto a ser comparado.
 * @see ComparadorEuclideano
 * @author Victor Williams Stafusa da Silva
 */
public interface ComparadorKnn<E> {

    /**
     * Calcula a distncia entre dois elementos, que nunca deve ser negativa.
     * @param elem1 O primeiro elemento.
     * @param elem2 O segundo elemento.
     * @return A distncia entre os dois elementos.
     * @throws IllegalArgumentException Se qualquer um dos parmetros for
     * {@code null} ou se no for possvel medir a distncia entre eles.
     */
    public double distancia(E elem1, E elem2);
}
