package br.usp.ime.mac5855.knn;

/**
 * Esta interface representa um objeto que informa os atributos dos elementos,
 * bem como as respectivas escalas.
 * @param <E> O tipo de objeto do qual os atributos so avaliados.
 * @see EscalonadorUniforme
 * @see EscalonadorMultiplicativo
 * @author Victor Williams Stafusa da Silva
 */
public interface Escalonador<E> {

    /**
     * Fornece os atributos de um dado elemento, sempre na mesma ordem e em
     * uma mesma quantidade.
     * @param elemento O elemento do qual deseja-se obter os valores dos
     * atributos
     * @return Os valores dos atributos correspondentes ao elemento dado.
     */
    public double[] valores(E elemento);

    /**
     * Escalona um determinado atributo.
     * @param numDimensao O ndice da dimenso correspondente a um atributo, de
     * acordo com o array retornado pelo mtodo {@linkplain #valores(Object)
     * valores(E)}.
     * @param valorOriginal O valor a ser escalonado.
     * @return O valor do atributo escalonado.
     */
    public double peso(int numDimensao, double valorOriginal);
}
