package br.usp.ime.mac5855.knn;

/**
 * Esta classe representa uma implementao parcial de escalonador, que sempre
 * d o mesmo peso para cada dimenso. Ou seja, no aplica nenhuma escala e
 * assume que todos os atributos tm a mesma escala.
 * Apenas o mtodo {@linkplain Escalonador#valores(Object)
 * Escalonador.valores(E)} deve ser implementado nas subclasses.
 * @param <E> O tipo de objeto do qual os atributos so avaliados.
 * @author Victor Williams Stafusa da Silva
 */
public abstract class EscalonadorUniforme<E> implements Escalonador<E> {

    /**
     * Construtor nico.
     */
    public EscalonadorUniforme() {}

    /**
     * Escalona um determinado atributo.
     * @param numDimensao O ndice da dimenso correspondente a um atributo, de
     * acordo com o array retornado pelo mtodo
     * {@linkplain Escalonador#valores(Object) Escalonador.valores(E)}. Uma vez
     * que esta classe simplesmente no escalona nada, assumindo que todos os
     * atributos tm a mesma escala, este parmetro  simplesmente ignorado.
     * @param valorOriginal O valor a ser escalonado. Como esta classe no
     * escalona nada, este valor  retornado sem nenhuma alterao.
     * @return O valor do parmetro {@code valorOriginal}.
     */
    @Override
    public double peso(int numDimensao, double valorOriginal) {
        return valorOriginal;
    }
}