package br.usp.ime.mac5855.knn;

/**
 * Esta interface especifica uma estratgia a ser usada pela classe
 * {@linkplain KnnPonderado} para comparar e ponderar objetos, alm de
 * determinar o nmero de vizinhos a ser usado.
 * <br />
 *  importante notar-se que no h nenhuma implementao padro para esta
 * interface.  responsabilidade do cdigo usurio implement-la.
 * @param <E> O tipo de objeto a ser avaliado na classe
 * {@linkplain KnnPonderado}.
 * @see KnnPonderado
 * @see ComparadorKnn
 * @see PonderadorKnn
 * @author Victor Williams Stafusa da Silva
 */
public interface KnnStrategy<E> {

    /**
     * Obtm um comparador de objetos, a ser usado no algoritmo Knn para
     * determinar distncias entre objetos.
     * @return O comparador de objetos.
     */
    public ComparadorKnn<E> getComparador();

    /**
     * Obtm um ponderador de distncias entre os objetos, a ser usado no
     * algoritmo Knn para dar pesos s distncias entre objetos.
     * @return O ponderador de distncias.
     */
    public PonderadorKnn getPonderador();

    /**
     * Obtm a quantidade de vizinhos (valor k) a ser usado no algoritmo Knn.
     * @return A quantidade de vizinhos.
     */
    public int getNumeroVizinhos();
}
