package br.usp.ime.mac5855.knn;

/**
 * Ponderador que pondera os valores subtraindo-os de uma constante dada (por
 * padro 1). Se o valor a ser subtrado for maior que a constante, zero 
 * retornado ao invs de um nmero negativo.
 * @author Victor Williams Stafusa da Silva
 */
public final class PonderadorSubtrativo implements PonderadorKnn {

    /** Constante usada como minuendo na subtrao. */
    private final double constanteBase;

    /**
     * Cria um {@code PonderadorSubtrativo} que subtrai de 1 o valor a ser
     * ponderado.
     */
    public PonderadorSubtrativo() {
        this(1.0);
    }

    /**
     * Cria um {@code PonderadorSubtrativo} com uma constante especfica, da
     * qual ser subtrada o valor a ser ponderado.
     * @param constanteBase A constante especfica da qual ser subtrada o
     * valor a ser ponderado.
     */
    public PonderadorSubtrativo(double constanteBase) {
        this.constanteBase = constanteBase;
    }

    /**
     * Obtm a constante usada como minuendo na pondero.
     * @return A constante usada como minuendo na pondero.
     */
    public double getConstanteBase() {
        return constanteBase;
    }

    /**
     * Pondera um valor representando uma distncia, que  sempre maior ou igual
     * a zero.
     * @param valor O valor a ser ponderado.
     * @return O valor aps a ponderao. Isso representa o mximo entre zero e
     * a diferena da constante especificada com o valor a ser ponderado.
     */
    @Override
    public double ponderar(double valor) {
        double valorPonderado = constanteBase - valor;
        return valorPonderado > 0.0 ? valorPonderado : 0.0;
    }
}