package br.usp.ime.mac5855.knn.validacaocruzada;

import br.usp.ime.mac5855.knn.KnnPonderado;

/**
 * Esta interface especifica a forma a ser usada para contabiliar o erro. Ao
 * ser informado o valor estimado e o valor real de algum item, o erro 
 * retornado. A definio exata do significado do valor do erro fica por conta
 * das implementaes desta iterface.
 *
 * @author Victor Williams Stafusa da Silva
 */
public interface AvaliadorErro {

    /**
     * Avalia o erro, dado o valor estimado e o valor real de um determinado
     * item.
     * @param valorEstimado O valor estimado pelo algoritmo
     * {@link KnnPonderado Knn} para algum determinado item.
     * @param valorReal O valor real do item.
     * @return O erro contabilizado neste item. A forma como este erro 
     * calculado e o significado exato deste valor fica a cargo de cada
     * implementao particular.
     */
    public double avaliarErro(double valorEstimado, double valorReal);
}
