package br.usp.ime.mac5855.knn.validacaocruzada;

import br.usp.ime.mac5855.knn.KnnPonderado;

/**
 * Especifica uma forma de contabilizar erros de estimativa por meio da
 * diferena entre o valor real e o valor estimado para um determinado item.
 *
 * @author Victor Williams Stafusa da Silva
 */
public final class AvaliadorErroValorAbsoluto implements AvaliadorErro {

    /**
     * Construtor nico.
     */
    public AvaliadorErroValorAbsoluto() {}

    /**
     * Avalia o erro, dado o valor estimado e o valor real de um determinado
     * item. O erro  estimado pela diferena entre os dois valores.
     * @param valorEstimado O valor estimado pelo algoritmo
     * {@link KnnPonderado Knn} para algum determinado item.
     * @param valorReal O valor real do item.
     * @return O erro contabilizado neste item.
     */
    @Override
    public double avaliarErro(double valorEstimado, double valorReal) {
        double diferenca = valorEstimado - valorReal;
        return diferenca < 0 ? -diferenca : diferenca;
    }
}
