package br.usp.ime.mac5855.knn.validacaocruzada;

import java.util.Set;

/**
 * Esta interface especifica a estratgia a ser usada pela classe
 * {@linkplain ValidacaoCruzada} para particionar os dados nos conjuntos de
 * treinamento e de teste.
 * @param <E> O tipo dos objeto a serem particionados.
 * @author Victor Williams Stafusa da Silva
 */
public interface Particionador<E> {

    /**
     * Particiona uma populao de dados em conjuntos de treinamento e de teste,
     * a serem obtidos posteriormente pelos mtodos
     * {@linkplain #getConjuntoTreinamento()} e
     * {@linkplain #getConjuntoTeste()}. Implementaes em particular devem a
     * cada vez que este mtodo  chamado, gerar um conjunto diferente de dados.
     * Para atingir tal objetivo, as implementaes podem valer-se de
     * particionar a populao aleatoriamente ou contar o nmero de vezes que
     * este mtodo  chamado.
     * @param populacao A populao de dados a ser particionada.
     * @throws IllegalArgumentException Se a populao informada for
     * {@code null}.
     */
    public void particionar(Set<E> populacao);

    /**
     * Obtm o conjunto de treinamento gerado pela ltima invocao ao mtodo
     * {@linkplain #particionar(Set)}. Tal conjunto  uma relao
     * @return O conjunto de treinamento.
     * @throws IllegalStateException Caso o mtodo
     * {@linkplain #particionar(Set)} ainda no tenha sido invocado.
     */
    public Set<E> getConjuntoTreinamento();

    /**
     * Obtm o conjunto de testo gerado pela ltima invocao ao mtodo
     * {@linkplain #particionar(Set)}.
     * @return O conjunto de teste.
     * @throws IllegalStateException Caso o mtodo
     * {@linkplain #particionar(Set)} ainda no tenha sido invocado.
     */
    public Set<E> getConjuntoTeste();
}
